@@ -1,11 +1,22 @@
 /*
- * VCD Player plugin for VDR
  * player.c: Player core
  *
- * See the README file for copyright information and how to reach the author.
+ * VCD Player plugin for VDR (the Video Disk Recorder)
+ * Copyright (C) 2002  Thomas Heiligenmann  <thomas@heiligenmann.de>
  *
- * This code is distributed under the terms and conditions of the
- * GNU GENERAL PUBLIC LICENSE. See the file COPYING for details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA
  *
  */
 
@@ -92,7 +103,7 @@ public:
   virtual bool GetReplayMode(bool &Play, bool &Forward, int &Sped);
   virtual void SetAudioTrack(eTrackType Type, const tTrackId *TrackId);
   const char *DeviceName(void) { return vcd->DeviceName(); }
-  };
+};
 
 int cVcdPlayer::Speeds[] = { 0, -2, -4, -8, 1, 2, 4, 12, 0 };
 
@@ -144,15 +155,14 @@ void cVcdPlayer::TrickSpeed(int Increment)
         Play();
      else
         Pause();
-     }
-  else if (Speeds[nts]) {
+  } else if (Speeds[nts]) {
      trickSpeed = nts;
      int Mult = (playMode == pmSlow && playDir == pdForward) ? 1 : SPEED_MULT;
      int sp = (Speeds[nts] > 0) ? Mult / Speeds[nts] : -Speeds[nts] * Mult;
      if (sp > MAX_VIDEO_SLOWMOTION)
         sp = MAX_VIDEO_SLOWMOTION;
      DeviceTrickSpeed(sp);
-     }
+  }
 }
 
 int cVcdPlayer::Resume(void)
@@ -172,12 +182,11 @@ void cVcdPlayer::Activate(bool On)
   if (On) {
      if (readTrack > 0)
         Start();
-     }
-  else if (active) {
+  } else if (active) {
      running = false;
      Cancel(3);
      active = false;
-     }
+  }
 }
 
 void cVcdPlayer::Empty(void)
@@ -205,24 +214,25 @@ void cVcdPlayer::Pause(void)
      if (playMode == pmFast || (playMode == pmSlow && playDir == pdBackward)) {
         done = false;
         Empty();
-        }
+     }
      DeviceFreeze();
      playMode = pmPause;
-     }
+  }
 }
 
 void cVcdPlayer::Play(void)
 {
   if (playMode != pmPlay) {
      LOCK_THREAD;
-     if (playMode == pmPause || playMode == pmStill || playMode == pmFast || (playMode == pmSlow && playDir == pdBackward)) {
+     if (playMode == pmPause || playMode == pmStill || playMode == pmFast ||
+           (playMode == pmSlow && playDir == pdBackward)) {
         done = false;
         Empty();
-        }
+     }
      DevicePlay();
      playMode = pmPlay;
      playDir = pdForward;
-     }
+  }
 }
 
 void cVcdPlayer::Forward(void)
@@ -232,11 +242,10 @@ void cVcdPlayer::Forward(void)
         if (Setup.MultiSpeedMode) {
            TrickSpeed(playDir == pdForward ? 1 : -1);
            break;
-           }
-        else if (playDir == pdForward) {
+        } else if (playDir == pdForward) {
            Play();
            break;
-           }
+        }
      // run into pmPlay
      case pmPlay: {
         LOCK_THREAD;
@@ -248,16 +257,15 @@ void cVcdPlayer::Forward(void)
         trickSpeed = NORMAL_SPEED;
         TrickSpeed(Setup.MultiSpeedMode ? 1 : MAX_SPEEDS);
         break;
-        }
+     }
      case pmSlow:
         if (Setup.MultiSpeedMode) {
            TrickSpeed(playDir == pdForward ? -1 : 1);
            break;
-           }
-        else if (playDir == pdForward) {
+        } else if (playDir == pdForward) {
            Pause();
            break;
-           }
+        }
      // run into pmPause
      case pmStill:
      case pmPause:
@@ -269,7 +277,7 @@ void cVcdPlayer::Forward(void)
         break;
      default:
         break;
-     }
+  }
 }
 
 void cVcdPlayer::Backward(void)
@@ -280,8 +288,7 @@ void cVcdPlayer::Backward(void)
            if (Setup.MultiSpeedMode) {
               TrickSpeed(playDir == pdBackward ? 1 : -1);
               break;
-              }
-           else if (playDir == pdBackward) {
+           } else if (playDir == pdBackward) {
               Play();
               break;
            }
@@ -296,16 +303,15 @@ void cVcdPlayer::Backward(void)
            trickSpeed = NORMAL_SPEED;
            TrickSpeed(Setup.MultiSpeedMode ? 1 : MAX_SPEEDS);
            break;
-           }
+        }
         case pmSlow:
            if (Setup.MultiSpeedMode) {
               TrickSpeed(playDir == pdBackward ? -1 : 1);
               break;
-              }
-           else if (playDir == pdBackward) {
+           } else if (playDir == pdBackward) {
               Pause();
               break;
-              }
+           }
         // run into pmPause
         case pmStill:
         case pmPause: {
@@ -317,9 +323,9 @@ void cVcdPlayer::Backward(void)
            playDir = pdBackward;
            trickSpeed = NORMAL_SPEED;
            TrickSpeed(Setup.MultiSpeedMode ? -1 : -MAX_SPEEDS);
-           }
-            break;
         }
+        break;
+     }
 }
 
 void cVcdPlayer::SkipSeconds(int Seconds)
@@ -335,10 +341,10 @@ void cVcdPlayer::SkipSeconds(int Seconds)
      else {
         doskip = true;
         readLba = lba;
-        }
+     }
      playMode = pmPause;
      Play();
-     }
+  }
 }
 
 void cVcdPlayer::Goto(int Position, bool Still)
@@ -352,7 +358,7 @@ void cVcdPlayer::Goto(int Position, bool Still)
      readLba = lba;
      if (Still)
         playMode = pmStill;
-     }
+  }
 }
 
 void cVcdPlayer::GotoTrack(int Track)
@@ -377,7 +383,7 @@ void cVcdPlayer::GotoEntry(int Entry)
      DevicePlay();
      playMode = pmPlay;
      playDir = pdForward;
-     }
+  }
 }
 
 bool cVcdPlayer::SkipTracks(int Tracks)
@@ -400,7 +406,7 @@ bool cVcdPlayer::SkipTracks(int Tracks)
      playMode = pmPlay;
      playDir = pdForward;
      return true;
-     }
+  }
   return false;
 }
 
@@ -425,9 +431,9 @@ bool cVcdPlayer::SkipEntries(int Entries)
               playMode = pmPlay;
               playDir = pdForward;
               return true;
-              }
            }
         }
+     }
      if (Entries < 0) {
         for (int i=U16_TO_LE(vcd->vcdEntries.entries); i>1; i--) {
            int pos = bcdmsf_to_lba(vcd->vcdEntries.entry[i-1].entry_msf);
@@ -445,10 +451,10 @@ bool cVcdPlayer::SkipEntries(int Entries)
               playMode = pmPlay;
               playDir = pdForward;
               return true;
-              }
            }
         }
      }
+  }
   return false;
 }
 
@@ -462,7 +468,7 @@ int cVcdPlayer::GetTrack(int Lba)
   int i;
   for (i=startTrack; i<=vcd->tracks; i++)
      if ((Lba >= vcd->vcdEntry[i].cdte_addr.lba) &&
-         (Lba < vcd->vcdEntry[i+1].cdte_addr.lba))
+           (Lba < vcd->vcdEntry[i+1].cdte_addr.lba))
         return i;
   return 0;
 }
@@ -499,7 +505,7 @@ void cVcdPlayer::Action(void)
      if (autoWait>=0 && fuse!=time(NULL)) {
         fuse = time(NULL);
         autoWait--;
-        }
+     }
      
      cPoller Poller;
      if (DevicePoll(Poller, 100)) {
@@ -518,11 +524,12 @@ void cVcdPlayer::Action(void)
            if (playFrame) {
               p = playFrame->Data();
               pc = playFrame->Count();
-              }
            }
+        }
 
         if (playFrame && autoWait<0) {
-           StripAudioPackets((uchar *)playFrame->Data(), playFrame->Count(), (playMode == pmFast || playMode == pmSlow) ? 0x00 : audioTrack);
+           StripAudioPackets((uchar *)playFrame->Data(), playFrame->Count(),
+              (playMode == pmFast || playMode == pmSlow) ? 0x00 : audioTrack);
            int w = PlayPes(p, pc);
            if (w > 0) {
               running = true;
@@ -532,23 +539,21 @@ void cVcdPlayer::Action(void)
                  writeLba = playFrame->Index();
                  ringBuffer->Drop(playFrame);
                  playFrame = NULL;
-                 }
               }
-           else if (w < 0 && FATALERRNO) {
+           } else if (w < 0 && FATALERRNO) {
               LOG_ERROR;
               break;
-              }
            }
+        }
         if (done) {
            if (!stop) sleep(1);
            running = false;
-           }
-
         }
-      else
+
+     } else
         sleep(1);
 
-     }
+  }
   active = running = false;
 
   dsyslog("VCD: input thread ended (pid=%d)", getpid());
@@ -572,34 +577,31 @@ cFrame *cVcdPlayer::getNextFrame(void)
            seqhdr_buf[5] = 0x01;
            seqhdr_buf[6] = 0x20;
            seqhdr_buf[7] = 0x23;
-           }
-        else {
+        } else {
            seqhdr_buf[4] = 0x16;   // NTSC VCD 352x240 4:3 30fps
            seqhdr_buf[5] = 0x00;
            seqhdr_buf[6] = 0xF0;
            seqhdr_buf[7] = 0x24;
-           }
         }
-     else {
+     } else {
         if (vcd->vcdInfo.video_type_map[(readTrack-1)/8] & (1 << (readTrack-1)%8)) {
            seqhdr_buf[4] = 0x1E;   // PAL SVCD 480x576 4:3 25fps
            seqhdr_buf[5] = 0x02;
            seqhdr_buf[6] = 0x40;
            seqhdr_buf[7] = 0x23;
-           }
-        else {
+        } else {
            seqhdr_buf[4] = 0x1E;   // NTSC SVCD 480x480 4:3 30fps
            seqhdr_buf[5] = 0x01;
            seqhdr_buf[6] = 0xE0;
            seqhdr_buf[7] = 0x24;
-           }
         }
+     }
      seqhdr_buf[8] = 0x00;
      seqhdr_buf[9] = 0x00;
      seqhdr_buf[10] = 0x20;
      seqhdr_buf[11] = 0x00;
      seqhdr_size = 12;
-     }
+  }
 
   int count = ReadSector(buffer);
 
@@ -608,11 +610,11 @@ cFrame *cVcdPlayer::getNextFrame(void)
         lba = lba0;
      else
         done = true;
-     }
+  }
  
   if (count > 0 &&
-      buffer[0] == 0x00 && buffer[1] == 0x00 && buffer[2] == 0x01 &&
-      buffer[3] == PACK_SC) {
+        buffer[0] == 0x00 && buffer[1] == 0x00 && buffer[2] == 0x01 &&
+        buffer[3] == PACK_SC) {
      int ofs;
      if (buffer[4] & 0xC0)     // MPEG-2 pack header
         ofs = 14 + (buffer[13] & 0x07);
@@ -637,8 +639,8 @@ cFrame *cVcdPlayer::getNextFrame(void)
                           seqhdr_size = j - i;
                           memcpy(seqhdr_buf, buffer+i, seqhdr_size);
                           break;
-                          }
                        }
+                    }
                     break;
                  case GROUP_OF_PICT_SC:
                     doskip = false;
@@ -655,12 +657,11 @@ cFrame *cVcdPlayer::getNextFrame(void)
                     if (picture_type == I_FRAME) {
                        for (int j=i+4; j < count-ofs-6; j++) {
                           if (buffer[j]   == 0x00 &&
-                              buffer[j+1] == 0x00 &&
-                              buffer[j+2] == 0x01 &&
-                              buffer[j+3] == USER_DATA_SC &&
-                              buffer[j+4] == 0x10 &&
-                              buffer[j+5] == 0x0E)
-                          {
+                                buffer[j+1] == 0x00 &&
+                                buffer[j+2] == 0x01 &&
+                                buffer[j+3] == USER_DATA_SC &&
+                                buffer[j+4] == 0x10 &&
+                                buffer[j+5] == 0x0E) {
                              if (buffer[j+6] != 0xFF)
                                 prev_i_lba = vcd->vcdEntry[readTrack].cdte_addr.lba +
                                    bcd_to_bin(buffer[j+8] & 0x7F) +
@@ -676,15 +677,15 @@ cFrame *cVcdPlayer::getNextFrame(void)
                              else
                                 next_i_lba = 0;
                              break;
-                             }
                           }
                        }
+                    }
                     break;
                  default:
                     break;
-                 }
               }
            }
+        }
         if (insert_seqhdr) {
            uchar tmp_buf[10*CD_XA22_DATASIZE];
            int new_pes_len = buffer[4]*256 + buffer[5] + seqhdr_size;
@@ -694,14 +695,13 @@ cFrame *cVcdPlayer::getNextFrame(void)
            buffer[4] = new_pes_len / 256;
            buffer[5] = new_pes_len % 256;
            count += seqhdr_size;
-           }
         }
+     }
  
 //FIXME: needs to be moved someplace else
      if (playMode == pmSlow && playDir == pdBackward) {
 // pending
-        }
-     else if (playMode == pmFast) {
+     } else if (playMode == pmFast) {
         if (picture_type != I_FRAME) {
            doskip = true;
            if (playDir == pdForward && next_i_lba)
@@ -714,10 +714,10 @@ cFrame *cVcdPlayer::getNextFrame(void)
                  playMode = pmPlay;
                  playDir = pdForward;
                  return 0;
-                 }
               }
            }
         }
+     }
  
      readLba = lba;
  
@@ -726,8 +726,8 @@ cFrame *cVcdPlayer::getNextFrame(void)
            return new cFrame(buffer, count-ofs, ftVideo, readLba);
         if ((strt_code & SC_MASK) == AUDIO_STREAM_SC && playMode == pmPlay)
            return new cFrame(buffer, count-ofs, ftAudio, readLba);
-        }
      }
+  }
 
   return 0;
 }
@@ -743,7 +743,7 @@ void cVcdPlayer::StripAudioPackets(uchar *b, int Length, uchar Except)
               if (strt_code==0xC1 && !canToggleAudioTrack) {
                  canToggleAudioTrack = true;
                  DeviceSetAvailableTrack(ttAudio, strt_code & 0x1f, strt_code);
-                 }
+              }
               if (!Except || strt_code!=Except)
                  memset(&b[i], 0x00, min(l, Length-i));
               break;
@@ -752,11 +752,11 @@ void cVcdPlayer::StripAudioPackets(uchar *b, int Length, uchar Except)
            default:
               l = 0;
               break;
-           }
+        }
         if (l)
            i += l - 1;
-        }
      }
+  }
 }
 
 void cVcdPlayer::TrackInit(int track)
@@ -768,11 +768,10 @@ void cVcdPlayer::TrackInit(int track)
   if (continuous) {
      lba0 = vcd->vcdEntry[startTrack].cdte_addr.lba;
      lba1 = vcd->vcdEntry[vcd->tracks+1].cdte_addr.lba;
-     }
-  else {
+  } else {
      lba0 = vcd->vcdEntry[track].cdte_addr.lba;
      lba1 = vcd->vcdEntry[track+1].cdte_addr.lba;
-     }
+  }
   lba = vcd->vcdEntry[track].cdte_addr.lba;
   seqhdr_size = 0;
   prev_i_lba = 0;
@@ -794,13 +793,13 @@ int cVcdPlayer::ReadSector(uchar *buf)
               return CD_XA22_DATASIZE;
            default:
               break;
-           }
         }
+     }
      if ((sector.subhead.b[2] & 0x10) && autoWaitInit>=0) {
         autoWait = autoWaitInit;
         dsyslog("VCD: autowait %d sec", autoWait);
-        }
      }
+  }
 
   return 0;
 }
@@ -811,8 +810,8 @@ void cVcdPlayer::SetAudioTrack(eTrackType Type, const tTrackId *TrackId)
      if ((audioTrack == 0xC0) != (Type <= ttAudioFirst)) {
         audioTrack = (Type > ttAudioFirst) ? 0xC1 : 0xC0;
         Empty();
-        }
      }
+  }
 }
 
 // --- cVcdPlayerControl -----------------------------------------------------
@@ -850,7 +849,7 @@ void cVcdPlayerControl::Stop(void)
      player->Stop();
      delete player;
      player = NULL;
-     }
+  }
 }
 
 void cVcdPlayerControl::Pause(void)
